InMemoryProvider

Struct InMemoryProvider 

pub struct InMemoryProvider { /* private fields */ }
In-memory queue provider implementation

Implementations

Source

impl InMemoryProvider

pub fn new(config: InMemoryConfig) -> Self

Create new in-memory provider with configuration

pub async fn accept_session( &self, queue: &QueueName, session_id: Option<SessionId>, ) -> Result<Box<dyn SessionClient>, QueueError>

Helper method to accept a session and return a SessionClient.

This is a convenience method for testing that wraps create_session_client. In production code, use QueueClient::accept_session() instead.